summaryrefslogtreecommitdiff
path: root/Source/Core/DiscIO/FileMonitor.cpp
diff options
context:
space:
mode:
authorJosJuice <josjuice@gmail.com>2014-12-25 11:12:04 +0100
committerJosJuice <josjuice@gmail.com>2014-12-25 11:12:04 +0100
commit1618d315237a88b7ebce4866cacf590c6fccbf07 (patch)
treead0f4959b9146f0db11a3f2e819199b4052cb00d /Source/Core/DiscIO/FileMonitor.cpp
parent8624461315c5baaf23b3d13a0365de69a95266e6 (diff)
FileMonitor: Get rid of "GC" from names and comments
Diffstat (limited to 'Source/Core/DiscIO/FileMonitor.cpp')
-rw-r--r--Source/Core/DiscIO/FileMonitor.cpp21
1 files changed, 11 insertions, 10 deletions
diff --git a/Source/Core/DiscIO/FileMonitor.cpp b/Source/Core/DiscIO/FileMonitor.cpp
index 6cb8c410ef..16c110716e 100644
--- a/Source/Core/DiscIO/FileMonitor.cpp
+++ b/Source/Core/DiscIO/FileMonitor.cpp
@@ -27,7 +27,7 @@ namespace FileMon
static DiscIO::IVolume *OpenISO = nullptr;
static DiscIO::IFileSystem *pFileSystem = nullptr;
-static std::vector<const DiscIO::SFileInfo *> GCFiles;
+static std::vector<const DiscIO::SFileInfo *> DiscFiles;
static std::string ISOFile = "", CurrentFile = "";
static bool FileAccess = true;
@@ -58,8 +58,8 @@ bool IsSoundFile(const std::string& filename)
}
-// Read the GC file system
-void ReadGC(const std::string& filename)
+// Read the file system
+void ReadFileSystem(const std::string& filename)
{
// Should have an actual Shutdown procedure or something
if (OpenISO != nullptr)
@@ -73,8 +73,8 @@ void ReadGC(const std::string& filename)
pFileSystem = nullptr;
}
- // GCFiles' pointers are no longer valid after pFileSystem is cleared
- GCFiles.clear();
+ // DiscFiles' pointers are no longer valid after pFileSystem is cleared
+ DiscFiles.clear();
OpenISO = DiscIO::CreateVolumeFromFilename(filename);
if (!OpenISO)
return;
@@ -86,8 +86,9 @@ void ReadGC(const std::string& filename)
if (!pFileSystem)
return;
- pFileSystem->GetFileList(GCFiles);
+ pFileSystem->GetFileList(DiscFiles);
}
+
FileAccess = true;
}
@@ -119,7 +120,7 @@ void CheckFile(const std::string& file, u64 size)
}
-// Find the GC filename
+// Find the filename
void FindFilename(u64 offset)
{
// Don't do anything if a game is not running
@@ -137,7 +138,7 @@ void FindFilename(u64 offset)
if (!pFileSystem || ISOFile != SConfig::GetInstance().m_LastFilename)
{
FileAccess = false;
- ReadGC(SConfig::GetInstance().m_LastFilename);
+ ReadFileSystem(SConfig::GetInstance().m_LastFilename);
ISOFile = SConfig::GetInstance().m_LastFilename;
INFO_LOG(FILEMON, "Opening '%s'", ISOFile.c_str());
return;
@@ -165,8 +166,8 @@ void Close()
pFileSystem = nullptr;
}
- // GCFiles' pointers are no longer valid after pFileSystem is cleared
- GCFiles.clear();
+ // DiscFiles' pointers are no longer valid after pFileSystem is cleared
+ DiscFiles.clear();
ISOFile = "";
CurrentFile = "";